==> deepin-terminal_6.0.7.tar.gz: BUILD/tests/src/common/ut_defines.h <==
// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef UT_DEFINES_TEST_H
#define UT_DEFINES_TEST_H

//UI测试等待时间间隔
#define UT_WAIT_TIME 10

//是否开启UI测试
#define ENABLE_UI_TEST

#define UT_UTILS_TEST
#define UT_SETTINGIO_TEST

#define UT_ENCODELISTVIEW_TEST
#define UT_ENCODEPANEL_TEST

#define UT_SWITCHTHEMEMENU_TEST
#define UT_MAINWINDOW_TEST
#define UT_SERVICE_TEST
#define UT_TERMPROPERTIES_TEST
#define UT_TERMINALAPPLICATION_TEST
#define UI_WINDOWSMANAGER_TEST

#define UT_SERVERCONFIGMANAGER_TEST
#define UT_SERVERCONFIGGROUPPANEL_TEST
#define UT_REMOTEMANAGEMENTTOPPANEL_TEST
#define UT_REMOTEMANAGEMENTSEARCHPANEL_TEST
#define UT_REMOTEMANAGEMENTPLUGIN_TEST
#define UT_REMOTEMANAGEMENTPANEL_TEST
#define UT_SERVERCONFIGOPTDLG_TEST

#define UT_SETTINGS_TEST
#define UT_SHORTCUTMANAGER_TEST

#define UT_THEMELISTVIEW_TEST
#define UT_THEMEPANEL_TEST

#define UT_LISTVIEW_TEST
#define UT_TABBAR_TEST
#define UT_ICONBUTTON_TEST
#define UT_MYICONBUTTON_TEST
#define UT_FOCUSFRAME_TEST
#define UT_ITEMWIDGET_TEST
#define UT_MYICONBUTTON_TEST
#define UT_OPERATIONCONFIRMDLG_TEST
#define UT_TERMINPUTDIALOG_TEST
#define UT_NEWDSPINBOX_TEST
#define UT_CUSTOMTHEMESETTINGDIALOG_TEST
#define UT_TITLE_STYLE_RADIOBUTTON_TEST
#define UT_COLOR_PUSHBUTTON_TEST

#define UT_DBUSMANAGER_TEST

#define UT_TERMWIDGETPAGE_TEST
#define UT_TERMWIDGET_TEST
#define UT_TITLEBAR_TEST
#define UT_PAGESEARCHBAR_TEST

#define UT_CUSTOMCOMMANDOPTDLG_TEST
#define UT_CUSTOMCOMMANDPANEL_TEST
#define UT_CUSTOMCOMMANDPLUGIN_TEST
#define UT_CUSTOMCOMMANDSEARCHRSTPANEL_TEST
#define UT_CUSTOMCOMMANDTOPPANEL_TEST

#define UT_TERMARGUMENTPARSER_TEST

//第三方库 QTermWidget 单元测试开关
#define UT_TERMINALDISPLAY_TEST
#define UT_VT102EMULATION_TEST
#define UT_SHELLCOMMAND_TEST
#define UT_SESSION_TEST
#define UT_SCREEN_TEST
#define UT_PTY_TEST
#define UT_HISTORY_TEST
#define UT_CHARACTER_TEST
#define UT_CHARACTERCOLOR_TEST
#define UT_COLORSCHEME_TEST
#define UT_QTERMWIDGET_TEST
#define UT_FILTER_TEST
#define UT_BLOCKARRAY_TEST
#define UT_SEARCHBAR_TEST
#define UT_KEYBOARDTRANSLATOR_TEST
#define UT_KPROCESS_TEST
#define UT_KPTY_TEST

#endif // UT_DEFINES_TEST_H

==> deepin-terminal_6.0.14.tar.gz: BUILD/tests/src/common/ut_defines.h <==
// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd
// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef UT_DEFINES_TEST_H
#define UT_DEFINES_TEST_H

//UI测试等待时间间隔
#define UT_WAIT_TIME 10

//是否开启UI测试
#define ENABLE_UI_TEST

#define UT_UTILS_TEST
#define UT_SETTINGIO_TEST

#define UT_ENCODELISTVIEW_TEST
#define UT_ENCODEPANEL_TEST

//#define UT_SWITCHTHEMEMENU_TEST
//#define UT_MAINWINDOW_TEST
#define UT_SERVICE_TEST
#define UT_TERMPROPERTIES_TEST
#define UT_TERMINALAPPLICATION_TEST
#define UI_WINDOWSMANAGER_TEST

#define UT_SERVERCONFIGMANAGER_TEST
#define UT_SERVERCONFIGGROUPPANEL_TEST
#define UT_REMOTEMANAGEMENTTOPPANEL_TEST
#define UT_REMOTEMANAGEMENTSEARCHPANEL_TEST
#define UT_REMOTEMANAGEMENTPLUGIN_TEST
#define UT_REMOTEMANAGEMENTPANEL_TEST
#define UT_SERVERCONFIGOPTDLG_TEST

#define UT_SETTINGS_TEST
#define UT_SHORTCUTMANAGER_TEST

#define UT_THEMELISTVIEW_TEST
#define UT_THEMEPANEL_TEST

#define UT_LISTVIEW_TEST
#define UT_TABBAR_TEST
#define UT_ICONBUTTON_TEST
#define UT_MYICONBUTTON_TEST
#define UT_FOCUSFRAME_TEST
#define UT_ITEMWIDGET_TEST
#define UT_MYICONBUTTON_TEST
#define UT_OPERATIONCONFIRMDLG_TEST
#define UT_TERMINPUTDIALOG_TEST
#define UT_NEWDSPINBOX_TEST
#define UT_CUSTOMTHEMESETTINGDIALOG_TEST
#define UT_TITLE_STYLE_RADIOBUTTON_TEST
#define UT_COLOR_PUSHBUTTON_TEST

#define UT_DBUSMANAGER_TEST

#define UT_TERMWIDGETPAGE_TEST
#define UT_TERMWIDGET_TEST
#define UT_TITLEBAR_TEST
#define UT_PAGESEARCHBAR_TEST

#define UT_CUSTOMCOMMANDOPTDLG_TEST
#define UT_CUSTOMCOMMANDPANEL_TEST
#define UT_CUSTOMCOMMANDPLUGIN_TEST
#define UT_CUSTOMCOMMANDSEARCHRSTPANEL_TEST
#define UT_CUSTOMCOMMANDTOPPANEL_TEST

#define UT_TERMARGUMENTPARSER_TEST

//第三方库 QTermWidget 单元测试开关
#define UT_TERMINALDISPLAY_TEST
#define UT_VT102EMULATION_TEST
#define UT_SHELLCOMMAND_TEST
#define UT_SESSION_TEST
#define UT_SCREEN_TEST
#define UT_PTY_TEST
#define UT_HISTORY_TEST
#define UT_CHARACTER_TEST
#define UT_CHARACTERCOLOR_TEST
#define UT_COLORSCHEME_TEST
#define UT_QTERMWIDGET_TEST
#define UT_FILTER_TEST
#define UT_BLOCKARRAY_TEST
#define UT_SEARCHBAR_TEST
#define UT_KEYBOARDTRANSLATOR_TEST
#define UT_KPROCESS_TEST
#define UT_KPTY_TEST

#endif // UT_DEFINES_TEST_H
